==> rendition-9.4.0.tgz: package/dist_esm5/components/Alert.js <==
import * as tslib_1 from "tslib";
import * as React from 'react';
import FaCheckCircle from 'react-icons/lib/fa/check-circle';
import FaClose from 'react-icons/lib/fa/close';
import FaExclamationCircle from 'react-icons/lib/fa/exclamation-circle';
import FaExclamationTriangle from 'react-icons/lib/fa/exclamation-triangle';
import FaInfoCircle from 'react-icons/lib/fa/info-circle';
import styled from 'styled-components';
import asRendition from '../asRendition';
import { bold, getColor, normal, px } from '../utils';
import { Flex } from './Grid';
var getPadding = function (props) {
    return props.emphasized ? '15px 40px' : '8px 32px';
};
var getTitle = function (props) {
    if (props.prefix === false) {
        return;
    }
    if (props.prefix !== undefined) {
        return props.prefix;
    }
    return props.danger
        ? 'Oh no!'
        : props.warning
            ? 'Warning!'
            : props.success
                ? 'Great!'
                : props.info
                    ? 'Hey!'
                    : '';
};
var AlertTitle = styled.span(templateObject_1 || (templateObject_1 = tslib_1.__makeTemplateObject(["\n\tdisplay: inline-flex;\n\tmargin-right: 8px;\n"], ["\n\tdisplay: inline-flex;\n\tmargin-right: 8px;\n"])));
var DismissButtonWrapper = styled.div(templateObject_2 || (templateObject_2 = tslib_1.__makeTemplateObject(["\n\tdisplay: inline-flex;\n\talign-items: center;\n\tjustify-content: center;\n\tposition: absolute;\n\ttop: 0;\n\tbottom: 0;\n\tright: ", ";\n"], ["\n\tdisplay: inline-flex;\n\talign-items: center;\n\tjustify-content: center;\n\tposition: absolute;\n\ttop: 0;\n\tbottom: 0;\n\tright: ", ";\n"])), function (props) { return px(props.emphasized ? 20 : 12); });
var DismissButton = styled.button(templateObject_3 || (templateObject_3 = tslib_1.__makeTemplateObject(["\n\tpadding: 0;\n\tborder: 0;\n\tbackground: none;\n\tline-height: 0;\n\tfont-size: 14px;\n\tcursor: pointer;\n\n\t&:hover {\n\t\tcolor: black;\n\t}\n"], ["\n\tpadding: 0;\n\tborder: 0;\n\tbackground: none;\n\tline-height: 0;\n\tfont-size: 14px;\n\tcursor: pointer;\n\n\t&:hover {\n\t\tcolor: black;\n\t}\n"])));
var AlertBase = styled.div(templateObject_4 || (templateObject_4 = tslib_1.__makeTemplateObject(["\n\tdisplay: flex;\n\talign-items: center;\n\tjustify-content: normal;\n\n\tposition: relative;\n\tmin-height: ", ";\n\tpadding: ", ";\n\tmargin: 0;\n\tborder-radius: ", ";\n\tfont-family: inherit;\n\tfont-size: 16px;\n\tfont-kerning: none;\n\tfont-weight: ", ";\n\tappearance: none;\n\ttext-decoration: none;\n\tvertical-align: middle;\n\tline-height: 1.1;\n"], ["\n\tdisplay: flex;\n\talign-items: center;\n\tjustify-content: normal;\n\n\tposition: relative;\n\tmin-height: ",
    ";\n\tpadding: ", ";\n\tmargin: 0;\n\tborder-radius: ", ";\n\tfont-family: inherit;\n\tfont-size: 16px;\n\tfont-kerning: none;\n\tfont-weight: ", ";\n\tappearance: none;\n\ttext-decoration: none;\n\tvertical-align: middle;\n\tline-height: 1.1;\n"])), function (props) {
    return px(props.emphasized ? props.theme.space[5] : props.theme.space[4]);
}, function (props) { return getPadding(props); }, function (props) { return px(props.theme.radius); }, function (props) { return normal(props); });
var Outline = styled(AlertBase)(templateObject_5 || (templateObject_5 = tslib_1.__makeTemplateObject(["\n\tpadding-left: 19px;\n\tborder: 1px solid ", ";\n\tbackground: ", ";\n\tcolor: ", ";\n\n\t& ", ", & ", " > ", " {\n\t\tfont-weight: ", ";\n\t\tcolor: ", ";\n\t}\n"], ["\n\tpadding-left: 19px;\n\tborder: 1px solid ", ";\n\tbackground: ", ";\n\tcolor: ", ";\n\n\t& ", ", & ", " > ", " {\n\t\tfont-weight: ", ";\n\t\tcolor: ", ";\n\t}\n"])), function (props) { return getColor(props, 'bg', 'main'); }, function (props) { return props.bg || getColor(props, 'bg', 'light'); }, function (props) { return props.theme.colors.text.main; }, AlertTitle, DismissButtonWrapper, DismissButton, function (props) { return bold(props); }, function (props) { return getColor(props, 'color', 'main'); });
var Filled = styled(AlertBase)(templateObject_6 || (templateObject_6 = tslib_1.__makeTemplateObject(["\n\tborder: 0;\n\tfont-weight: ", ";\n\ttext-align: center;\n\tbackground: ", ";\n\tcolor: ", ";\n"], ["\n\tborder: 0;\n\tfont-weight: ", ";\n\ttext-align: center;\n\tbackground: ", ";\n\tcolor: ", ";\n"])), function (props) { return bold(props); }, function (props) { return props.bg || getColor(props, 'bg', 'main'); }, function (props) { return props.color || '#fff'; });
var Plaintext = styled(AlertBase)(templateObject_7 || (templateObject_7 = tslib_1.__makeTemplateObject(["\n\tmin-height: auto;\n\tpadding: 0;\n\tfont-size: 14px;\n\n\t&,\n\t& ", " > ", " {\n\t\tcolor: ", ";\n\t}\n"], ["\n\tmin-height: auto;\n\tpadding: 0;\n\tfont-size: 14px;\n\n\t&,\n\t& ", " > ", " {\n\t\tcolor: ",
    ";\n\t}\n"])), DismissButtonWrapper, DismissButton, function (props) {
    return props.color ||
        (props.info
            ? props.theme.colors.gray.main
            : getColor(props, 'color', 'main'));
});
var getIcon = function (props) {
    if (props.prefix === false) {
        return;
    }
    if (props.prefix !== undefined) {
        return props.prefix;
    }
    return props.danger ? (React.createElement(FaExclamationCircle, null)) : props.warning ? (React.createElement(FaExclamationTriangle, null)) : props.success ? (React.createElement(FaCheckCircle, null)) : props.info ? (React.createElement(FaInfoCircle, null)) : ('');
};
var DismissAlert = function (_a) {
    var onDismiss = _a.onDismiss;
    return (React.createElement(DismissButtonWrapper, null,
        React.createElement(DismissButton, { onClick: function () { return onDismiss && onDismiss(); } },
            React.createElement(FaClose, null))));
};
var Alert = function (props) {
    var emphasized = props.emphasized, plaintext = props.plaintext, prefix = props.prefix, onDismiss = props.onDismiss, restProps = tslib_1.__rest(props, ["emphasized", "plaintext", "prefix", "onDismiss"]);
    var title = plaintext ? getIcon(props) : getTitle(props);
    if (plaintext) {
        return (React.createElement(Plaintext, tslib_1.__assign({}, restProps),
            React.createElement(Flex, null,
                title && React.createElement(AlertTitle, { children: title }),
                React.createElement("div", null, props.children)),
            onDismiss && React.createElement(DismissAlert, { onDismiss: onDismiss })));
    }
    else if (emphasized) {
        return (React.createElement(Filled, tslib_1.__assign({ emphasized: true }, restProps),
            React.createElement("div", null,
                title && React.createElement(AlertTitle, { children: title }),
                props.children),
            onDismiss && React.createElement(DismissAlert, { onDismiss: onDismiss })));
    }
    else {
        return (React.createElement(Outline, tslib_1.__assign({}, restProps),
            React.createElement("div", null,
                title && React.createElement(AlertTitle, { children: title }),
                props.children),
            onDismiss && React.createElement(DismissAlert, { onDismiss: onDismiss })));
    }
};
export default asRendition(Alert, [], ['bg']);
var templateObject_1, templateObject_2, templateObject_3, templateObject_4, templateObject_5, templateObject_6, templateObject_7;

==> rendition-9.10.0.tgz: package/dist_esm5/components/Alert.js <==
import * as tslib_1 from "tslib";
import * as React from 'react';
import FaCheckCircle from 'react-icons/lib/fa/check-circle';
import FaClose from 'react-icons/lib/fa/close';
import FaExclamationCircle from 'react-icons/lib/fa/exclamation-circle';
import FaExclamationTriangle from 'react-icons/lib/fa/exclamation-triangle';
import FaInfoCircle from 'react-icons/lib/fa/info-circle';
import styled from 'styled-components';
import asRendition from '../asRendition';
import { bold, getColor, normal, px } from '../utils';
import { Flex } from './Grid';
var getPadding = function (props) {
    return props.emphasized ? '15px 40px' : '8px 32px';
};
var getTitle = function (props) {
    if (props.prefix === false) {
        return;
    }
    if (props.prefix !== undefined) {
        return props.prefix;
    }
    return props.danger
        ? 'Oh no!'
        : props.warning
            ? 'Warning!'
            : props.success
                ? 'Great!'
                : props.info
                    ? 'Hey!'
                    : '';
};
var AlertTitle = styled.span(templateObject_1 || (templateObject_1 = tslib_1.__makeTemplateObject(["\n\tdisplay: inline-flex;\n\tmargin-right: 8px;\n"], ["\n\tdisplay: inline-flex;\n\tmargin-right: 8px;\n"])));
var DismissButtonWrapper = styled.div(templateObject_2 || (templateObject_2 = tslib_1.__makeTemplateObject(["\n\tdisplay: inline-flex;\n\talign-items: center;\n\tjustify-content: center;\n\tposition: absolute;\n\ttop: 0;\n\tbottom: 0;\n\tright: ", ";\n"], ["\n\tdisplay: inline-flex;\n\talign-items: center;\n\tjustify-content: center;\n\tposition: absolute;\n\ttop: 0;\n\tbottom: 0;\n\tright: ", ";\n"])), function (props) { return px(props.emphasized ? 20 : 12); });
var DismissButton = styled.button(templateObject_3 || (templateObject_3 = tslib_1.__makeTemplateObject(["\n\tpadding: 0;\n\tborder: 0;\n\tbackground: none;\n\tline-height: 0;\n\tfont-size: 14px;\n\tcursor: pointer;\n\n\t&:hover {\n\t\tcolor: black;\n\t}\n"], ["\n\tpadding: 0;\n\tborder: 0;\n\tbackground: none;\n\tline-height: 0;\n\tfont-size: 14px;\n\tcursor: pointer;\n\n\t&:hover {\n\t\tcolor: black;\n\t}\n"])));
var AlertBase = styled.div(templateObject_4 || (templateObject_4 = tslib_1.__makeTemplateObject(["\n\tdisplay: flex;\n\talign-items: center;\n\tjustify-content: normal;\n\n\tposition: relative;\n\tmin-height: ", ";\n\tpadding: ", ";\n\tmargin: 0;\n\tborder-radius: ", ";\n\tfont-family: inherit;\n\tfont-size: 16px;\n\tfont-kerning: none;\n\tfont-weight: ", ";\n\tappearance: none;\n\ttext-decoration: none;\n\tvertical-align: middle;\n\tline-height: 1.1;\n"], ["\n\tdisplay: flex;\n\talign-items: center;\n\tjustify-content: normal;\n\n\tposition: relative;\n\tmin-height: ",
    ";\n\tpadding: ", ";\n\tmargin: 0;\n\tborder-radius: ", ";\n\tfont-family: inherit;\n\tfont-size: 16px;\n\tfont-kerning: none;\n\tfont-weight: ", ";\n\tappearance: none;\n\ttext-decoration: none;\n\tvertical-align: middle;\n\tline-height: 1.1;\n"])), function (props) {
    return px(props.emphasized ? props.theme.space[5] : props.theme.space[4]);
}, function (props) { return getPadding(props); }, function (props) { return px(props.theme.radius); }, function (props) { return normal(props); });
var Outline = styled(AlertBase)(templateObject_5 || (templateObject_5 = tslib_1.__makeTemplateObject(["\n\tpadding-left: 19px;\n\tborder: 1px solid ", ";\n\tbackground: ", ";\n\tcolor: ", ";\n\n\t& ", ", & ", " > ", " {\n\t\tfont-weight: ", ";\n\t\tcolor: ", ";\n\t}\n"], ["\n\tpadding-left: 19px;\n\tborder: 1px solid ", ";\n\tbackground: ", ";\n\tcolor: ", ";\n\n\t& ", ", & ", " > ", " {\n\t\tfont-weight: ", ";\n\t\tcolor: ", ";\n\t}\n"])), function (props) { return getColor(props, 'bg', 'main'); }, function (props) { return props.bg || getColor(props, 'bg', 'light'); }, function (props) { return props.theme.colors.text.main; }, AlertTitle, DismissButtonWrapper, DismissButton, function (props) { return bold(props); }, function (props) { return getColor(props, 'color', 'main'); });
var Filled = styled(AlertBase)(templateObject_6 || (templateObject_6 = tslib_1.__makeTemplateObject(["\n\tborder: 0;\n\tfont-weight: ", ";\n\ttext-align: center;\n\tbackground: ", ";\n\tcolor: ", ";\n"], ["\n\tborder: 0;\n\tfont-weight: ", ";\n\ttext-align: center;\n\tbackground: ", ";\n\tcolor: ", ";\n"])), function (props) { return bold(props); }, function (props) { return props.bg || getColor(props, 'bg', 'main'); }, function (props) { return props.color || '#fff'; });
var Plaintext = styled(AlertBase)(templateObject_7 || (templateObject_7 = tslib_1.__makeTemplateObject(["\n\tmin-height: auto;\n\tpadding: 0;\n\tfont-size: ", ";\n\n\t&,\n\t& ", " > ", " {\n\t\tcolor: ", ";\n\t}\n"], ["\n\tmin-height: auto;\n\tpadding: 0;\n\tfont-size: ", ";\n\n\t&,\n\t& ", " > ", " {\n\t\tcolor: ",
    ";\n\t}\n"])), function (props) { return px(props.theme.fontSizes[1]); }, DismissButtonWrapper, DismissButton, function (props) {
    return props.color ||
        (props.info
            ? props.theme.colors.gray.main
            : getColor(props, 'color', 'main'));
});
var getIcon = function (props) {
    if (props.prefix === false) {
        return;
    }
    if (props.prefix !== undefined) {
        return props.prefix;
    }
    return props.danger ? (React.createElement(FaExclamationCircle, null)) : props.warning ? (React.createElement(FaExclamationTriangle, null)) : props.success ? (React.createElement(FaCheckCircle, null)) : props.info ? (React.createElement(FaInfoCircle, null)) : ('');
};
var DismissAlert = function (_a) {
    var onDismiss = _a.onDismiss;
    return (React.createElement(DismissButtonWrapper, null,
        React.createElement(DismissButton, { onClick: function () { return onDismiss && onDismiss(); } },
            React.createElement(FaClose, null))));
};
var Alert = function (props) {
    var emphasized = props.emphasized, plaintext = props.plaintext, prefix = props.prefix, onDismiss = props.onDismiss, restProps = tslib_1.__rest(props, ["emphasized", "plaintext", "prefix", "onDismiss"]);
    var title = plaintext ? getIcon(props) : getTitle(props);
    if (plaintext) {
        return (React.createElement(Plaintext, tslib_1.__assign({}, restProps),
            React.createElement(Flex, null,
                title && React.createElement(AlertTitle, { children: title }),
                React.createElement("div", null, props.children)),
            onDismiss && React.createElement(DismissAlert, { onDismiss: onDismiss })));
    }
    else if (emphasized) {
        return (React.createElement(Filled, tslib_1.__assign({ emphasized: true }, restProps),
            React.createElement("div", null,
                title && React.createElement(AlertTitle, { children: title }),
                props.children),
            onDismiss && React.createElement(DismissAlert, { onDismiss: onDismiss })));
    }
    else {
        return (React.createElement(Outline, tslib_1.__assign({}, restProps),
            React.createElement("div", null,
                title && React.createElement(AlertTitle, { children: title }),
                props.children),
            onDismiss && React.createElement(DismissAlert, { onDismiss: onDismiss })));
    }
};
export default asRendition(Alert, [], ['bg']);
var templateObject_1, templateObject_2, templateObject_3, templateObject_4, templateObject_5, templateObject_6, templateObject_7;
